@@ -39,7 +39,7 @@ def chromedriver():
 
 
 @chromedriver.command()
-@click.argument('target_dir', type=click.Path(path_type=Path))
+@click.argument('target_dir', type=click.Path(path_type=Path), required=False)
 def download(target_dir):
     """
     Downloads the latest chromedriver for your Chrome Browser.
@@ -50,6 +50,8 @@ def download(target_dir):
 
     Results in `/tmp/chromedriver-
     """
+    if target_dir is None:
+        target_dir = Path()
     if not target_dir.is_dir():
         raise ClickException(f'not a directory: {target_dir}')
     try:
